''' Utils '''
DATA2022 = {
    'domain': 'pretalx.com',
    'project': 'coscup-2022',
    'resource': 'talks',
}

DATA2023 = {
    'domain': 'pretalx.coscup.org',
    'project': 'coscup-2023-call-for-participation',
    'resource': 'talks',
}
